@@ -1,19 +1,17 @@
-import {Component} from "@angular/core";
-
+import { Component } from "@angular/core"
 
 /* This file is here to make the admin site compile, since there is a public
-angular module that depends on it.
+ angular module that depends on it.
  */
 
 @Component({
-    selector: 'core-device-loading',
-    template: '<p>nothing</p>',
-    moduleId: module.id
+    selector: "core-device-loading",
+    template: "<p>nothing</p>"
 })
 export class LoadingComponent {
-
+    
     constructor() {
-
+    
     }
-
-}
\ No newline at end of file
+    
+}
