@@ -1,7 +1,7 @@
 from vortex.handler.TupleActionProcessor import TupleActionProcessor
 
-from peek_core_device._private.PluginNames import deviceFilt
 from peek_core_device._private.PluginNames import deviceActionProcessorName
+from peek_core_device._private.PluginNames import deviceFilt
 from .controller.MainController import MainController
 
 
@@ -9,5 +9,6 @@ def makeTupleActionProcessorHandler(mainController: MainController):
     processor = TupleActionProcessor(
         tupleActionProcessorName=deviceActionProcessorName,
         additionalFilt=deviceFilt,
-        defaultDelegate=mainController)
+        defaultDelegate=mainController,
+    )
     return processor
