@@ -1,4 +1,5 @@
-from vortex.Tuple import addTupleType, TupleField
+from vortex.Tuple import TupleField
+from vortex.Tuple import addTupleType
 from vortex.TupleAction import TupleActionABC
 
 from peek_core_device._private.PluginNames import deviceTuplePrefix
@@ -8,7 +9,7 @@ from peek_core_device._private.PluginNames import deviceTuplePrefix
 class EnrolDeviceAction(TupleActionABC):
     __tupleType__ = deviceTuplePrefix + "EnrolDeviceAction"
 
-    description:str = TupleField()
+    description: str = TupleField()
     deviceId: str = TupleField()
     deviceType: str = TupleField()
-    appVersion: str = TupleField()
\ No newline at end of file
+    appVersion: str = TupleField()
